==> haskell-text-latin1-0.3.1-212-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-vuw8PxaGIp9aHVute3kXR
key:                  text-latin1-0.3.1-vuw8PxaGIp9aHVute3kXR
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  5663635cebf28c2e9f6aa5cf276f027b
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-vuw8PxaGIp9aHVute3kXR
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-latin1-0.3.1-214-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-text-latin1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 text-latin1
version:              0.3.1
visibility:           public
id:                   text-latin1-0.3.1-eddX6rd3rE4Ec9P7DfFGE
key:                  text-latin1-0.3.1-eddX6rd3rE4Ec9P7DfFGE
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/text-latin1
synopsis:             Latin-1 (including ASCII) utility functions
description:
    This package provides various functions over the ASCII ang Latin-1
    portions of the '\''Char'\'' and '\''Word8'\'' data types.

category:             Text
abi:                  251bf59535736cc2957b0305594eab1f
exposed:              True
exposed-modules:      Text.Ascii Text.Latin1
import-dirs:          /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/text-latin1-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-latin1
hs-libraries:         HStext-latin1-0.3.1-eddX6rd3rE4Ec9P7DfFGE
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-text-latin1/html/text-latin1.haddock
haddock-html:         /usr/share/doc/haskell-text-latin1/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
